@@ -1,6 +1,7 @@
         
 class M1CNNPreprocessing:
-    def preprocess_features(dataframe):
+    @staticmethod
+    def preprocess_features(self, dataframe):
         from EIMTC.plugins.n_bytes import NBytes
         NBytes.preprocess(dataframe)
         
